==> nextcloud-23.0.9.tgz: nextcloud/apps/dashboard/l10n/uz.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking.",
    "Customize" : "Customize",
    "Edit widgets" : "Edit widgets",
    "Get more widgets from the App Store" : "Get more widgets from the App Store",
    "Change background image" : "Change background image",
    "Weather service" : "Weather service",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information.",
    "Weather data from Met.no" : "Weather data from Met.no",
    "geocoding with Nominatim" : "geocoding with Nominatim",
    "elevation data from OpenTopoData" : "elevation data from OpenTopoData",
    "Weather" : "Weather",
    "Status" : "Status",
    "Good morning" : "Good morning",
    "Good morning, {name}" : "Good morning, {name}",
    "Good afternoon" : "Good afternoon",
    "Good afternoon, {name}" : "Good afternoon, {name}",
    "Good evening" : "Good evening",
    "Good evening, {name}" : "Good evening, {name}",
    "Hello" : "Hello",
    "Hello, {name}" : "Hello, {name}",
    "Pick from Files" : "Pick from Files",
    "Default image" : "Default image",
    "Plain background" : "Plain background",
    "Insert from {productName}" : "Insert from {productName}",
    "Show something" : "Show something",
    "Default images" : "Default images"
},
"nplurals=1; plural=0;");

==> nextcloud-24.0.10.tgz: nextcloud/apps/dashboard/l10n/uz.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking.",
    "Customize" : "Customize",
    "Edit widgets" : "Edit widgets",
    "Get more widgets from the App Store" : "Get more widgets from the App Store",
    "Weather service" : "Weather service",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information.",
    "Weather data from Met.no" : "Weather data from Met.no",
    "geocoding with Nominatim" : "geocoding with Nominatim",
    "elevation data from OpenTopoData" : "elevation data from OpenTopoData",
    "Weather" : "Weather",
    "Status" : "Status",
    "Good morning" : "Good morning",
    "Good morning, {name}" : "Good morning, {name}",
    "Good afternoon" : "Good afternoon",
    "Good afternoon, {name}" : "Good afternoon, {name}",
    "Good evening" : "Good evening",
    "Good evening, {name}" : "Good evening, {name}",
    "Hello" : "Hello",
    "Hello, {name}" : "Hello, {name}",
    "Change background image" : "Change background image",
    "Pick from Files" : "Pick from Files",
    "Default images" : "Default images",
    "Plain background" : "Plain background",
    "Insert from {productName}" : "Insert from {productName}"
},
"nplurals=1; plural=0;");
